@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun May 25 2003
     copyright            : (C) 2003 by Thach Nguyen
-    email                : thach@dragon.thach.com
+    email                : thach.nguyen@rmit.edu.au
  ***************************************************************************/
 
 /***************************************************************************
@@ -42,7 +42,7 @@ void print_entry ( FILE *fp, BibEntry *e, char ld, char rd )
 
 	for ( i=0; i < e-> getNoFields(); i++ )
 	{
-		if ( e->getField ( i ) [0] >= ' ' )
+		if ( !(e->getField(i)).isEmpty())
 		{
 
 
@@ -758,10 +758,14 @@ int caseless_find ( const char *haystack,char *needle, bool caseless )
 	int skip_braces=1,dyn_alloc=0;
 	char *aux,*p;
 	char prebuf[256];
-
-	lh=strlen ( haystack );
-	ln=strlen ( needle );
-
+	if (haystack!=0)
+		lh=strlen ( haystack );
+	else
+		lh = 0;
+	if (needle!=0)
+		ln=strlen ( needle );
+	else
+		ln = 0;
 	if ( ( lh==0 ) && ( ln==0 ) )
 		return 1;
 	if ( lh==0 )
