@@ -461,6 +461,12 @@ EntrezConfigWidget::EntrezConfigWidget ( QWidget* parent_, EntrezSearcher* searc
 	m_searcher = searcher_;
 	QVBoxLayout* l = new QVBoxLayout ( optionsWidget() );
 	l->addWidget ( new QLabel ( i18n ( "This source has no options." ), optionsWidget() ) );
+	KURLLabel *urlLab = new KURLLabel( optionsWidget() );
+	l->addWidget(urlLab);
+	urlLab->setText( "More information about Pubmed");
+        urlLab->setURL("http://www.ncbi.nlm.nih.gov/sites/entrez?db=PubMed");
+    
+	connect(urlLab , SIGNAL( leftClickedURL( const QString& ) ), kapp, SLOT( invokeBrowser( const QString& ) ) );
 	l->addStretch();
 }
 
