@@ -37,7 +37,9 @@ public:
 	QString fieldName() { return m_name; }
 	int labelWidth() {return m_label->sizeHint().width(); } 
 	void setLabelWidth(int w);
-
+signals:
+  virtual void modified();
+  
 protected:
 	RefField* m_field;
 	QString m_name;
