@@ -176,6 +176,8 @@ void ID2Entry::slotComplete(KIO::Job* job_) {
 		emit signalResultFound(0);
 		return;
 	}
+	QString str = QString::fromUtf8(m_data, m_data.size());
+
 
 	if(m_data.isEmpty()) {
 		KMessageBox::error( (KBibApp*) parent(),i18n("No data was received."));
@@ -256,39 +258,80 @@ void ID2Entry::parseCrossRef(){
 										entry->setField(QString::fromLatin1("journal"), e.text());	
 									
 								}	
-								else if (nodeName == QString::fromLatin1("author") ){
-									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("author"), e.text());	
+								else if (nodeName == QString::fromLatin1("contributors") ){
+									RefField *field = BibEntryDefTable::self()->getRefField(QString::fromLatin1("author"));
+									QString linkSt;
+									if (field)
+										linkSt = field->connectingString;
+									else
+										linkSt = QString::fromLatin1(" and ");
+									QString author;
+									for ( QDomNode q = p.firstChild(); !q.isNull(); q = q.nextSibling() )
+									{
+										QString nodeName_ = q.nodeName();
+										if (nodeName_ == QString::fromLatin1("contributor") ){
+											QString name;
+											QDomNode r;
+											r = q.namedItem(QString::fromLatin1("surname") );
+											if (!r.isNull()){
+												name = r.toElement().text();
+											}
+											if (!name.isEmpty() ){
+												r = q.namedItem(QString::fromLatin1("given_name") );
+												if (!r.isNull()){
+													QString givenName;
+													givenName = r.toElement().text();
+													if (!givenName.isEmpty()){
+														name = name + QString::fromLatin1(", ") + givenName;
+													}
+												}
+											}
+											if (!name.isEmpty()){
+												if (author.isEmpty() )
+													author = name;
+												else
+													author = author + linkSt + name;
+											}
+										}
+	
+
+									}	
+
+
+									if(!author.isEmpty())
+										entry->setField(QString::fromLatin1("author"), author);	
 									
 								}	
 								else if (nodeName == QString::fromLatin1("volume") ){
 									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("volume"), e.text());	
+										entry->setField(QString::fromLatin1("volume"), text);	
 									
 								}	
 								else if (nodeName == QString::fromLatin1("issue") ){
 									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("number"), e.text());	
+										entry->setField(QString::fromLatin1("number"), text);	
 									
 								}	
 								else if (nodeName == QString::fromLatin1("first_page") ){
 									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("pages"), e.text());	
+										entry->setField(QString::fromLatin1("pages"), text);	
 									
 								}	
 								else if (nodeName == QString::fromLatin1("year") ){
 									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("year"), e.text());	
+										entry->setField(QString::fromLatin1("year"), text);	
 									
 								}	
 								else if (nodeName == QString::fromLatin1("article_title") ){
-									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("title"), e.text());	
-									
+									if(!text.isEmpty()){
+										text.remove(QString::fromLatin1("<![CDATA[") );
+										text.remove(QString::fromLatin1("]]>") );
+										entry->setField(QString::fromLatin1("title"), text);	
+									}
 								}	
 								else if (nodeName == QString::fromLatin1("volume_title") ){
 									if(!text.isEmpty())
-										entry->setField(QString::fromLatin1("booktitle"), e.text());	
+										entry->setField(QString::fromLatin1("booktitle"), text);	
 									
 								}	
 							}	
