@@ -715,7 +715,13 @@ IEEEXploreConfigWidget::IEEEXploreConfigWidget(QWidget* parent_, IEEEXploreSearc
     QWhatsThis::add(m_freeSearchSelect, w);
     l->addWidget(m_freeSearchSelect);
 
-    //l->addWidget(new QLabel(i18n("This source has no options."), optionsWidget()));
+    KURLLabel *urlLab = new KURLLabel( optionsWidget() );
+    l->addWidget(urlLab);
+    urlLab->setText( "More information about IEEEXplore");
+    urlLab->setURL("http://ieeexplore.ieee.org");
+    
+    connect(urlLab , SIGNAL( leftClickedURL( const QString& ) ), kapp, SLOT( invokeBrowser( const QString& ) ) );
+
     l->addStretch();
 
     if(searcher_)
