@@ -43,10 +43,18 @@
 #include "woksearcher.h"
 #include "scholarsearcher.h"
 #include "citebasesearcher.h"
+#include "arxivsearcher.h"
+#include "spiressearcher.h"
+#include "scitationsearcher.h"
 
 SourceListViewItem::SourceListViewItem ( KListView* parent_, QListViewItem* after_,searcher *s )
 		: KListViewItem ( parent_, after_, s->source() ), m_searcher ( s )
-{}
+{
+	QPixmap pix = searchManager::searcherIcon(s);
+	if(!pix.isNull()) {
+    		setPixmap(0, pix);
+  	}
+}
 
 SourceListViewItem::~SourceListViewItem()
 {
@@ -753,15 +761,7 @@ void KBibConfigDlg::readDataSourceConfig()
 	{
 		SourceListViewItem* item = new SourceListViewItem ( m_sourceListView, m_sourceListView->lastItem(), s );
 		item->setNewSource ( false );
-		//		item->setFetcher(s);
-		/*
-		Fetch::ConfigWidget* cw = it->configWidget(this);
-		if(cw) { // might return 0 when no widget available for fetcher type
-			m_configWidgets.insert(item, cw);
-		    // there's weird layout bug if it's not hidden
-			cw->hide();
-		}
-		*/
+		
 	}
 
 	if ( m_sourceListView->childCount() == 0 )
@@ -915,6 +915,25 @@ void KBibConfigDlg::slotNewSourceClicked()
 			}
 			break;
 
+			case ArXiv:
+			{
+				ArXivSearcher *arxivSearcher = new ArXivSearcher ( this );
+				s = arxivSearcher;
+			}
+			break;
+
+			case Spires:
+			{
+				SpiresSearcher *spiresSearcher = new SpiresSearcher ( this );
+				s = spiresSearcher;
+			}
+			break;
+			case Scitation:
+			{
+				ScitationSearcher *scitationSearcher = new ScitationSearcher ( this );
+				s = scitationSearcher;
+			}
+			break;
 
 			default:
 				break;
@@ -1144,7 +1163,29 @@ void KBibConfigDlg::slotPresetSourceClicked()
 	item->setNewSource ( true );
 	item->setText ( 0, s->source() );
 
+	//arXiv
+	ArXivSearcher *arxivSearcher = new ArXivSearcher ( this );
+	arxivSearcher->setSource ( QString ( "arXiv" ) );
+	s = arxivSearcher;
+	item = new SourceListViewItem ( m_sourceListView, m_sourceListView->lastItem(), s );
+	item->setNewSource ( true );
+	item->setText ( 0, s->source() );
 
+	//Spires
+	SpiresSearcher *spiresSearcher = new SpiresSearcher ( this );
+	spiresSearcher->setSource ( QString ( "Spires-HEP" ) );
+	s = spiresSearcher;
+	item = new SourceListViewItem ( m_sourceListView, m_sourceListView->lastItem(), s );
+	item->setNewSource ( true );
+	item->setText ( 0, s->source() );
+
+	//Scitation
+	ScitationSearcher *scitationSearcher = new ScitationSearcher ( this );
+	scitationSearcher->setSource ( QString ( "Scitation" ) );
+	s = scitationSearcher;
+	item = new SourceListViewItem ( m_sourceListView, m_sourceListView->lastItem(), s );
+	item->setNewSource ( true );
+	item->setText ( 0, s->source() );
 
 	m_modifySourceBtn->setEnabled ( true );
 	m_removeSourceBtn->setEnabled ( true );
