@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Jun 7 2003
     copyright            : (C) 2003 by Thach Nguyen
-    email                : thach@dragon.thach.com
+    email                : thach.nguyen@rmit.edu.au
  ***************************************************************************/
 
 /***************************************************************************
