@@ -24,7 +24,7 @@ public:
     virtual QString cite();
     virtual void setActive();
 protected:
-    KBibIface_stub() : DCOPStub( never_use ) {};
+    KBibIface_stub() : DCOPStub( never_use ) {}
 };
 
 
