@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon May 26 2003
     copyright            : (C) 2003 by Thach Nguyen
-    email                : thach@dragon.thach.com
+    email                : thach.nguyen@rmit.edu.au
  ***************************************************************************/
 
 /***************************************************************************
@@ -913,12 +913,6 @@ vector<int> *KBibListView::deleteSelected(void)
 
 void KBibListView::viewSelected(void)
 {
-    if (selectedItems().isEmpty())
-    {
-        return ;
-    }
-    else
-    {
         unsigned int list_size = this->getListSize();
         KBibListViewItem *item;
         for (unsigned int i = 0; i< list_size; i++)
@@ -935,7 +929,7 @@ void KBibListView::viewSelected(void)
         }
 
 
-    }
+    
 }
 
 
@@ -1040,8 +1034,7 @@ void KBibListView::showByRefType(QString refType)
         thisEntry = thisItem->getBibEntry();
 		if (thisEntry->getEntryType() != refType)
 		{
-            list_view->remove
-            (i);
+            list_view->remove(i);
             i--;
             listSize--;
         }
