@@ -33,7 +33,6 @@ KBibRemoteSearchDlg::KBibRemoteSearchDlg ( QWidget *parent, const char *name )
 {
 
 	m_started = false;
-//	m_manager = new searchManager();
 	QWidget* mainWidget = new QWidget ( this, "Remote Search" );
 	setMainWidget ( mainWidget );
 	QVBoxLayout* topLayout = new QVBoxLayout ( mainWidget, 0, KDialog::spacingHint() );
@@ -46,7 +45,12 @@ KBibRemoteSearchDlg::KBibRemoteSearchDlg ( QWidget *parent, const char *name )
 
 	QLabel* label = new QLabel ( i18n ( "Search s&ource:" ), box0 );
 	dataSource = new KComboBox ( box0 );
-	dataSource->insertStringList ( searchManager::self()->sources() );
+	QStringList sources = searchManager::self()->sources();
+	for (int i = 0; i < sources.count(); i++){
+		QString source = sources[i];
+		searcher *s = searchManager::self()->searcherFromName(source);
+		dataSource->insertItem( searchManager::self()->searcherIcon(s), source);
+	}
 	label->setBuddy ( dataSource );
 	QWhatsThis::add ( dataSource, i18n ( "Select the database to search" ) );
 
@@ -54,7 +58,6 @@ KBibRemoteSearchDlg::KBibRemoteSearchDlg ( QWidget *parent, const char *name )
 	QWidget *simpleWidget = new  QWidget ( queryTab );
 	queryTab->addTab ( simpleWidget, i18n("Simple search") );
 	
-	//QVGroupBox* simpleBox = new QVGroupBox (simpleWidget, "Simple Query Box" );
 	QVBoxLayout* simpleBox = new QVBoxLayout ( simpleWidget,  KDialog::marginHint(), 0 );
 	
 	QHBox* box1 = new QHBox ( simpleWidget, "box1" );
@@ -177,11 +180,16 @@ KBibRemoteSearchDlg::KBibRemoteSearchDlg ( QWidget *parent, const char *name )
 	topLayout->addWidget ( box7 );
 	box7->setSpacing ( KDialog::spacingHint() );
 
-	addButton = new KPushButton ( i18n ( "&Add References" ), box7 );
-	addButton->setGuiItem ( KGuiItem ( i18n ( "&Add References" ),
+	addButton = new KPushButton ( i18n ( "Add Selected References" ), box7 );
+	addButton->setGuiItem ( KGuiItem ( i18n ( "Add References" ),
 	                                   SmallIconSet ( QString::fromLatin1 ( "add" ) ) ) );
 	addButton->setEnabled ( false );
 
+	addAllButton = new KPushButton ( i18n ( "Add All References" ), box7 );
+	addAllButton->setGuiItem ( KGuiItem ( i18n ( "Add All References" ),
+	                                   SmallIconSet ( QString::fromLatin1 ( "apply" ) ) ) );
+	addAllButton->setEnabled ( false );
+
 
 	this->setMinimumWidth ( 600 );
 
@@ -190,6 +198,8 @@ KBibRemoteSearchDlg::KBibRemoteSearchDlg ( QWidget *parent, const char *name )
 	connect ( dataSource, SIGNAL ( activated ( const QString& ) ), SLOT ( slotSourceSelected ( const QString& ) ) );
 
 	connect ( addButton, SIGNAL ( clicked() ), SLOT ( slotAddEntryClick() ) );
+	connect ( addAllButton, SIGNAL ( clicked() ), SLOT ( slotAddAllEntryClick() ) );
+	
 
 	clearButton = new KPushButton ( KStdGuiItem::clear(), box7 );
 
@@ -377,6 +387,7 @@ void KBibRemoteSearchDlg::slotResultFound ( BibEntry* bib )
 		displayFields << "author" << "year" << "title";
 		KBibListViewItem * item = new KBibListViewItem ( listView, doc, new BibEntry ( *bib ), displayFields, 0 );
 		delete bib;
+		addAllButton->setEnabled ( true );
 	}
 }
 
@@ -418,6 +429,19 @@ void KBibRemoteSearchDlg::slotAddEntryClick()
 	}
 }
 
+void KBibRemoteSearchDlg::slotAddAllEntryClick()
+{
+	KBibApp *win = ( KBibApp * ) ( this->parent() );
+	KBibDoc *doc = win->getDocument();
+
+	for ( QListViewItem* item_ = listView->firstChild(); item_; item_ = item_->nextSibling() )
+	{
+		KBibListViewItem *item = dynamic_cast<KBibListViewItem*> ( item_ );
+		BibEntry *e =  item->getBibEntry();
+		doc->addEntry ( new BibEntry ( *e ), ignoreExistingSelect->isChecked(), createKeySelect->isChecked() );
+	}
+}
+
 void KBibRemoteSearchDlg::slotClearClick()
 {
 	//Remove bib pointers first
@@ -432,6 +456,7 @@ void KBibRemoteSearchDlg::slotClearClick()
 	entryPreview->clear();
 	searchTerms1->setFocus();
 	slotSelectionChanged();
+	addAllButton->setEnabled ( false );
 
 }
 
