@@ -41,6 +41,7 @@ public:
 		void slotSourceSelected(const QString&);
 		void slotSearchClick();
 		void slotAddEntryClick();	
+		void slotAddAllEntryClick();
 		void slotClearClick();
 		void slotEntryClicked(QListViewItem *);
 		void slotEntryDoubleClicked(QListViewItem *);
@@ -64,6 +65,7 @@ private:
 	QCheckBox* ignoreExistingSelect;
 	QCheckBox* createKeySelect;
 	KPushButton* addButton;
+	KPushButton* addAllButton;
 	KPushButton* clearButton;
 	KURLLabel* querySyntaxURLLab; 
 	
