@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Apr 9 2004
     copyright            : (C) 2004 by Thach Nguyen
-    email                : thach@dragon.thach.com
+    email                : thach.nguyen@rmit.edu.au
  ***************************************************************************/
 
 /***************************************************************************
