@@ -24,7 +24,7 @@
 #include "kbib.h"
 
 static const char *description =
-    I18N_NOOP ( "KBib - A BibTeX management program for KDE\nBibTeX file processing code is based on gbib v0.1.2\nImporting/exporting filters are based on bibutils v3.27" );
+    I18N_NOOP ( "KBib - A bibliography reference manager for KDE\nBibTeX file processing code is based on gbib v0.1.2\nImporting/exporting filters are based on bibutils v3.27" );
 
 
 
@@ -41,7 +41,7 @@ int main ( int argc, char *argv[] )
 {
 	KAboutData aboutData ( "kbib", I18N_NOOP ( "KBib" ),
 	                       VERSION, description, KAboutData::License_GPL,
-	                       "(c) 2003-2006, Thach Nguyen", 0, "http://user.digisurf.com.au/~thachly/kbib", "thach.nguyen@rmit.edu.au" );
+	                       "(c) 2003-2008, Thach Nguyen", 0, "http://user.digisurf.com.au/~thachly/kbib", "thach.nguyen@rmit.edu.au" );
 	aboutData.addAuthor ( "Thach Nguyen",0, "thach.nguyen@rmit.edu.au" );
 	KCmdLineArgs::init ( argc, argv, &aboutData );
 	KCmdLineArgs::addCmdLineOptions ( options ); // Add our own options.
