@@ -12,8 +12,8 @@
 #ifndef NEWENTRYFROMTEXTDIALOG_H
 #define NEWENTRYFROMTEXTDIALOG_H
 
+#include "config.h"
 #include <kdialogbase.h>
-
 class KPushButton;
 class KComboBox;
 class KTextEdit;
@@ -38,20 +38,23 @@ public:
 		void slotOpenClicked();	
 		void slotEntryTypeChange(int);
 		void slotSelectionChanged();
-		void slotFieldMenuActivated(int);
-	
+		void slotSetFieldMenuActivated(int);
+		void slotAddFieldMenuActivated(int);	
 private:
 	BibEntry* m_entry;
 	KPushButton *m_clear;
 	KPushButton *m_paste;
 	KPushButton *m_open;
+#if HAVE_POPPLER
 	KPushButton *m_pdf;
+#endif
 //	KPushButton *m_assign;
 	KComboBox *m_entryType;
 	KTextEdit *m_edit;	
 	KTextEdit *entryPreview;
 	KPopupMenu* m_fieldMenu;
-	
+	KPopupMenu *setToFieldSubMenu;
+	KPopupMenu *addToFieldSubMenu;
 };
 
 #endif
