@@ -26,7 +26,10 @@ enum Type {
   IEEEXplore,
   WOK,
   Scholar,
-  Citebase
+  Citebase,
+  ArXiv,
+  Spires,
+  Scitation
 };
 
 enum SearchKey {
@@ -37,7 +40,8 @@ enum SearchKey {
 	Subject,
 	Journal,
 	Year,
- 	Topic
+ 	Topic,
+	Abstract
 };
 
 class QStringList;
