@@ -19,6 +19,9 @@
 #include "woksearcher.h"
 #include "scholarsearcher.h"
 #include "citebasesearcher.h"
+#include "arxivsearcher.h"
+#include "spiressearcher.h"
+#include "scitationsearcher.h"
 
 #include <klocale.h>
 #include <klineedit.h>
@@ -244,7 +247,27 @@ void SearcherConfigDlg::slotNewSourceSelected(const QString& type_)
             m_configWidget = citebaseCw;
         }
         break;
-	 		
+	 	
+     case ArXiv:
+        {
+            ArXivConfigWidget *ArXivCw = new ArXivConfigWidget(widget, 0);
+            m_configWidget = ArXivCw;
+        }
+        break;
+
+     case Spires:
+        {
+            SpiresConfigWidget *spiresCw = new SpiresConfigWidget(widget, 0);
+            m_configWidget = spiresCw;
+        }
+        break;
+     case Scitation:
+        {
+            ScitationConfigWidget *scitationCw = new ScitationConfigWidget(widget, 0);
+            m_configWidget = scitationCw;
+        }
+        break;
+	
 	default:
         return;
     }
