@@ -17,10 +17,17 @@
 #include "woksearcher.h"
 #include "scholarsearcher.h"
 #include "citebasesearcher.h"
+#include "arxivsearcher.h"
+#include "spiressearcher.h"
+#include "scitationsearcher.h"
 
 #include <kglobal.h>
 #include <kconfig.h>
 #include <klocale.h>
+#include <kiconloader.h>
+#include <kmimetype.h>
+#include <kstandarddirs.h>
+#include <dcopref.h>
 #include <iostream>
 
 #include <config.h>
@@ -42,7 +49,9 @@ searchManager::searchManager() : QObject()
     m_keyMap.insert(All,        i18n("All fields"));
     m_keyMap.insert(Journal,        i18n("Journal"));
     m_keyMap.insert(Year,    i18n("Year"));
-	m_keyMap.insert(Topic,    i18n("Topic"));
+    m_keyMap.insert(Topic,    i18n("Topic"));
+    m_keyMap.insert(Subject,    i18n("Subject"));
+    m_keyMap.insert(Abstract,    i18n("Abstract"));
 }
 
 searchManager::~searchManager()
@@ -135,8 +144,17 @@ searcher* searchManager::createSearcher(KConfig* config_, const QString& group_)
     case Citebase:
         f = new CitebaseSearcher(this);
         break;
-
+    case ArXiv:
+	f = new ArXivSearcher(this);
+	break;
+    case Spires:
+	f = new SpiresSearcher(this);
+	break;
+    case Scitation:
+	f = new ScitationSearcher(this);
+	break;
     case Unknown:
+	break;
     default:
         break;
     }
@@ -282,6 +300,9 @@ QString searchManager::typeName(Type type_)
 	case WOK: return WOKSearcher::defaultName();
 	case Scholar: return ScholarSearcher::defaultName();
 	case Citebase: return CitebaseSearcher::defaultName();
+	case ArXiv: return ArXivSearcher::defaultName();
+	case Spires: return SpiresSearcher::defaultName();
+	case Scitation: return ScitationSearcher::defaultName();
     default: break;
     }
     return QString::null;
@@ -305,8 +326,88 @@ SearchMap searchManager::sourceMap()
 	map.insert(WOK, WOKSearcher::defaultName());
 	map.insert(Scholar, ScholarSearcher::defaultName());
 	map.insert(Citebase, CitebaseSearcher::defaultName());
+	map.insert(ArXiv, ArXivSearcher::defaultName() );
+	map.insert(Spires, SpiresSearcher::defaultName() );
+	map.insert(Scitation, ScitationSearcher::defaultName() );
     return map;
 }
 
+searcher* searchManager::searcherFromName(QString source){
+  searcher *s;
+  for ( s = searchersList.first(); s; s = searchersList.next() )
+    {
+        if(source == s->source())
+        {
+		return s;
+	}
+  }
+	return 0;
+}
+
+QPixmap searchManager::searcherIcon(searcher *s) {
+        if (!s)
+	return QPixmap();
+#if HAVE_YAZ
+		if(s->type() == Z3950){
+			Z3950Searcher *searcher = dynamic_cast<Z3950Searcher*>(s);
+			KURL u;
+			u.setProtocol(QString::fromLatin1("http"));
+			u.setHost(searcher->host());
+			QString icon = favIcon(u);
+			if(u.isValid() && !icon.isEmpty()) {
+      				return SmallIcon(icon);
+    			}
+  		} 
+		else
+#endif
+			return searcherIcon(s->type());	
+	
+}
+
+
+QPixmap searchManager::searcherIcon(Type type_) {
+  QString name;
+  switch(type_) {
+    case Z3950:
+      name = QString::fromLatin1("network"); break; // rather arbitrary
+    case SRU:
+      name = QString::fromLatin1("network_local"); break; // just to be different than z3950
+    case Entrez:
+      name = favIcon("http://www.ncbi.nlm.nih.gov"); break;    
+    case IEEEXplore:
+      name = favIcon("http://ieeexplore.ieee.org"); break;
+    case WOK:
+      name = favIcon("http://scientific.thomson.com"); break;
+    case Scholar:
+      name = favIcon("http://scholar.google.com"); break;		
+    case ArXiv:
+      name = favIcon("http://arxiv.org"); break;
+    case Citebase:
+      name = favIcon("http://citebase.org"); break;
+    case Spires:
+      name = favIcon("http://www.slac.stanford.edu/spires"); break;
+    case Scitation:
+      name = favIcon("http://scitation.aip.org"); break;
+    default: break;
+  }
+
+  return name.isEmpty() ? QPixmap() : SmallIcon(name);
+}
+
+QString searchManager::favIcon(const KURL& url_) {
+  DCOPRef kded("kded", "favicons");
+  DCOPReply reply = kded.call("iconForURL(KURL)", url_);
+  QString iconName = reply.isValid() ? reply : QString();
+  if(!iconName.isEmpty()) {
+    return iconName;
+  } else {
+    // go ahead and try to download it for later
+    kded.call("downloadHostIcon(KURL)", url_);
+  }
+  return KMimeType::iconForURL(url_);
+}
+
+
+
 
 //#include "../searchmanager.moc"
