@@ -43,9 +43,12 @@ public:
   QString helpURL(const QString& source);
   int maxSearchTerms(const QString& source_);
   void retrieveRange(unsigned int, unsigned int);
-
+  searcher *searcherFromName(QString source);
   static QString typeName(Type type);
   static SearchMap sourceMap();
+  static QPixmap searcherIcon(searcher *s);
+  static QPixmap searcherIcon(Type type);
+
   
 signals:
   void signalResultFound(BibEntry* e);  
@@ -57,6 +60,7 @@ private slots:
   
 private:
   static searchManager* s_self;
+  static QString favIcon(const KURL& url);
   searcher* createSearcher(KConfig* config, const QString& configGroup);
   QPtrList<searcher> searchersList;
   SearchKeyMap m_keyMap;
