@@ -675,6 +675,12 @@ WOKConfigWidget::WOKConfigWidget(QWidget* parent_, WOKSearcher* searcher_ /*=0*/
     QWhatsThis::add(label, w);
     QWhatsThis::add(m_dataBaseCombo, w);
     label->setBuddy(m_dataBaseCombo);
+    KURLLabel *urlLab = new KURLLabel( optionsWidget() );
+	l->addWidget(urlLab, ++row, 0);
+	urlLab->setText( "More information about WoK");
+        urlLab->setURL("http://www.isiwebofknowledge.com/");
+    
+	connect(urlLab , SIGNAL( leftClickedURL( const QString& ) ), kapp, SLOT( invokeBrowser( const QString& ) ) );
 
     l->setRowStretch(++row, 1);
 
