@@ -95,7 +95,9 @@ QString Z3950Searcher::defaultName()
 
 QString Z3950Searcher::source() const
 {
-    return m_name.isEmpty() ? defaultName() : m_name;
+	if (!m_name.isEmpty())
+		return m_name;
+	return m_host.isEmpty() ? defaultName() : m_host;
 }
 
 void Z3950Searcher::setSource(const QString s)
@@ -491,23 +493,7 @@ void Z3950Searcher::handleResult(const QString& result_)
 		}
 		delete entryList;
 		
-/*		
-		
-		BibEntry *bib;
-        FILE *inf = fopen("/tmp/kbib-z3950-mods.bib", "r");
 
-        if (!inf)
-            return;
-        while(!feof(inf))
-        {
-//            bib=read_entry(inf, 0);
-            if (bib)
-            {
-                emit signalResultFound(new BibEntry(*bib));
-                delete bib;
-            }
-        }
-*/
     }
 
 }
